@@ -1,18 +1,23 @@
-# -*- Mode: python; tab-width: 4; indent-tabs-mode:nil; -*-
+# -*- Mode: python; tab-width: 4; indent-tabs-mode:nil; coding:utf-8 -*-
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
 #
-# MDAnalysis --- http://mdanalysis.googlecode.com
-# Copyright (c) 2006-2011 Naveen Michaud-Agrawal,
-#               Elizabeth J. Denning, Oliver Beckstein,
-#               and contributors (see website for details)
+# MDAnalysis --- https://www.mdanalysis.org
+# Copyright (c) 2006-2017 The MDAnalysis Development Team and contributors
+# (see the file AUTHORS for the full list of names)
+#
 # Released under the GNU Public Licence, v2 or any higher version
 #
 # Please cite your use of MDAnalysis in published work:
 #
-#     N. Michaud-Agrawal, E. J. Denning, T. B. Woolf, and
-#     O. Beckstein. MDAnalysis: A Toolkit for the Analysis of
-#     Molecular Dynamics Simulations. J. Comput. Chem. 32 (2011), 2319--2327,
-#     doi:10.1002/jcc.21787
+# R. J. Gowers, M. Linke, J. Barnoud, T. J. E. Reddy, M. N. Melo, S. L. Seyler,
+# D. L. Dotson, J. Domanski, S. Buchoux, I. M. Kenney, and O. Beckstein.
+# MDAnalysis: A Python package for the rapid analysis of molecular dynamics
+# simulations. In S. Benthall and S. Rostrup editors, Proceedings of the 15th
+# Python in Science Conference, pages 102-109, Austin, TX, 2016. SciPy.
+#
+# N. Michaud-Agrawal, E. J. Denning, T. B. Woolf, and O. Beckstein.
+# MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
+# J. Comput. Chem. 32 (2011), 2319--2327, doi:10.1002/jcc.21787
 #
 
 """
@@ -37,6 +42,9 @@ The raw tables are stored in the strings
 .. autodata:: TABLE_ATOMELEMENTS
 .. autodata:: TABLE_MASSES
 """
+from __future__ import absolute_import
+from ._elements import NUMBER_TO_ELEMENT
+
 
 def kv2dict(s, convertor=str):
     """Primitive ad-hoc parser of a key-value record list.
@@ -60,7 +68,7 @@ def kv2dict(s, convertor=str):
     lines = s.splitlines()
     for line in lines:
         line = line.lstrip()
-        values = line.split(None,1)
+        values = line.split(None, 1)
         if len(values) == 0 or line.startswith("#"):
             continue
         d[values[0]] = convertor(values[1])
@@ -70,13 +78,16 @@ def kv2dict(s, convertor=str):
 #: with :func:`MDAnalysis.topology.core.guess_atom_element`.
 TABLE_ATOMELEMENTS = """
 # translation of atomnames to types/element
-# based on CHARMM and AMBER usage with a little bit of GROMOS
+# based on CHARMM and AMBER usage with a little bit of GROMOS (and PROPKA)
 # NOTE: CL might be ambiguous and is interpreted as chloride!
 
 # --------- ------------------
 # atomname   element
 # --------- ------------------
 
+# Bromide
+BR           BR
+
 # Calcium
 CAL          CA
 C0           CA
@@ -91,8 +102,12 @@ CLAL         CL
 CL           CL
 CL-          CL
 
+# Iodide
+IOD          I
+
 # Iron
 FE           FE
+FE2          FE
 
 # Lithium
 LIT          LI
@@ -111,6 +126,7 @@ MG2+         MG
 ##NE           NE
 
 # Potassium
+K            K
 POT          K
 K+           K
 QK           K
@@ -143,6 +159,9 @@ QR           RB
 BC           C
 AC           C
 
+# dummy atom types
+MW           DUMMY
+
 # other types are guessed from the name; see
 # topology.core.guess_atom_elements()
 """
@@ -159,30 +178,134 @@ TABLE_MASSES = """
 #------------ -----------
 # atomtype    mass
 #------------ -----------
-H               1.00800
-C              12.01100
-N              14.00700
-O              15.99900
-S              32.06000
-P              30.97400
-HE              4.00260
-NE             20.17970
-FE             55.84700
-NA             22.98977
-K              39.10200
-RB             85.46780
-CS            132.90000
-MG             24.30500
-CA             40.08000
-CU             63.54600
-ZN             65.37000
-Ce            140.11600
-F              18.99800
-CL             35.45000
-BR             79.90400
-I             126.90450
+Ac    227.028
+Al    26.981539
+Am    243
+Sb    121.757
+Ar    39.948
+As    74.92159
+At    210
+Ba    137.327
+Bk    247
+Be    9.012182
+Bi    208.98037
+Bh    262
+B     10.811
+BR    79.90400
+Cd    112.411
+CA    40.08000
+Cf    251
+C     12.01100
+Ce    140.11600
+CS    132.90000
+CL    35.45000
+Cr    51.9961
+Co    58.9332
+CU    63.54600
+Cm    247
+Db    262
+Dy    162.5
+Es    252
+Er    167.26
+Eu    151.965
+Fm    257
+F     18.99800
+Fr    223
+Gd    157.25
+Ga    69.723
+Ge    72.61
+Au    196.96654
+Hf    178.49
+Hs    265
+HE    4.00260
+Ho    164.93032
+H     1.00800
+In    114.82
+I     126.90450
+Ir    192.22
+FE    55.84700
+Kr    83.8
+La    138.9055
+Lr    262
+Pb    207.2
+Li    6.941
+Lu    174.967
+MG    24.30500
+Mn    54.93805
+Mt    266
+Md    258
+Hg    200.59
+Mo    95.94
+N     14.00700
+NA    22.98977
+Nd    144.24
+NE    20.17970
+Np    237.048
+Ni    58.6934
+Nb    92.90638
+No    259
+Os    190.2
+O     15.99900
+Pd    106.42
+P     30.97400
+Pt    195.08
+Pu    244
+Po    209
+K     39.10200
+Pr    140.90765
+Pm    145
+Pa    231.0359
+Ra    226.025
+Rn    222
+Re    186.207
+Rh    102.9055
+RB    85.46780
+Ru    101.07
+Rf    261
+Sm    150.36
+Sc    44.95591
+Sg    263
+Se    78.96
+Si    28.0855
+Ag    107.8682
+Na    22.989768
+Sr    87.62
+S     32.06000
+Ta    180.9479
+Tc    98
+Te    127.6
+Tb    158.92534
+Tl    204.3833
+Th    232.0381
+Tm    168.93421
+Sn    118.71
+Ti    47.88
+W     183.85
+U     238.0289
+V     50.9415
+Xe    131.29
+Yb    173.04
+Y     88.90585
+ZN    65.37000
+Zr    91.224
+DUMMY 0.0
 """
 
 #: Dictionary table with atomic masses in u, indexed by the element from
 #: :data:`atomelements`.
 masses = kv2dict(TABLE_MASSES, convertor=float)
+
+#: Van der Waals radii (taken from GROMACS_, ``/usr/share/gromacs/top/vdwradii.dat``)
+#: and converted to ångström.
+#: .. _GROMACS: http://www.gromacs.org
+#:
+#: .. SeeAlso:: :func:`MDAnalysis.topology.core.guess_bonds`
+vdwradii = {
+    "C":     1.5,
+    "F":     1.2,
+    "H":     0.4,
+    "N":     1.10,
+    "O":     1.05,
+    "S":     1.6,
+    "P":     1.6,
+}
